import { defineComponent, provide, computed } from "vue";
import { usePermission } from "/@/hooks/usePermission";
import NoAuth from "./no-auth.vue";
import "./style.scss";

const PageAuth = defineComponent({
  name: "PageAuth",
  props: {
    pageName: {
      type: String
    },
    margin: {
      type: Boolean,
      default: true
    }
  },
  setup(props, { slots }) {
    const { permissions, hasPermissionWithCode } = usePermission(
      props.pageName
    );

    const classes = computed(() => {
      const { margin } = props;
      return margin ? "" : "auth__container--nomargin";
    });

    provide<AuthProvide>("Auth", {
      permissions
    });

    return () =>
      hasPermissionWithCode("001") ? (
        <div class={classes.value}>{slots.default && slots.default()}</div>
      ) : (
        <NoAuth />
      );
  }
});

export default PageAuth;
